@@ -3,11 +3,12 @@ Interface for Chinese Robotell compatible interfaces (win32/linux).
 """
 
 import io
-import time
 import logging
+import time
 from typing import Optional
 
-from can import BusABC, Message
+from can import BusABC, CanProtocol, Message
+
 from ..exceptions import CanInterfaceNotImplementedError, CanOperationError
 
 logger = logging.getLogger(__name__)
@@ -91,6 +92,7 @@ class robotellBus(BusABC):
         if bitrate is not None:
             self.set_bitrate(bitrate)
 
+        self._can_protocol = CanProtocol.CAN_20
         self.channel_info = (
             f"Robotell USB-CAN s/n {self.get_serial_number(1)} on {channel}"
         )
@@ -396,7 +398,7 @@ class robotellBus(BusABC):
 
         serial = ""
         for idx in range(0, 8, 2):
-            serial += "{:02X}{:02X}-".format(sn1[idx], sn1[idx + 1])
+            serial += f"{sn1[idx]:02X}{sn1[idx + 1]:02X}-"
         for idx in range(0, 4, 2):
-            serial += "{:02X}{:02X}-".format(sn2[idx], sn2[idx + 1])
+            serial += f"{sn2[idx]:02X}{sn2[idx + 1]:02X}-"
         return serial[:-1]
