@@ -2,21 +2,19 @@
 Contains handling of ASC logging files.
 
 Example .asc files:
-    - https://bitbucket.org/tobylorenz/vector_asc/src/47556e1a6d32c859224ca62d075e1efcc67fa690/src/Vector/ASC/tests/unittests/data/CAN_Log_Trigger_3_2.asc?at=master&fileviewer=file-view-default
+    - https://bitbucket.org/tobylorenz/vector_asc/src/master/src/Vector/ASC/tests/unittests/data/
     - under `test/data/logfile.asc`
 """
-import re
-from typing import Any, Generator, List, Optional, Dict, Union, TextIO
-
-from datetime import datetime
-import time
 import logging
+import re
+import time
+from datetime import datetime
+from typing import Any, Dict, Generator, List, Optional, TextIO, Union
 
 from ..message import Message
-from ..util import channel2int, len2dlc, dlc2len
-from .generic import FileIOMessageWriter, MessageReader
 from ..typechecking import StringPathLike
-
+from ..util import channel2int, dlc2len, len2dlc
+from .generic import TextIOMessageReader, TextIOMessageWriter
 
 CAN_MSG_EXT = 0x80000000
 CAN_ID_MASK = 0x1FFFFFFF
@@ -26,7 +24,7 @@ BASE_DEC = 10
 logger = logging.getLogger("can.io.asc")
 
 
-class ASCReader(MessageReader):
+class ASCReader(TextIOMessageReader):
     """
     Iterator of CAN messages from a ASC logging file. Meta data (comments,
     bus statistics, J1939 Transport Protocol messages) is ignored.
@@ -39,7 +37,6 @@ class ASCReader(MessageReader):
         file: Union[StringPathLike, TextIO],
         base: str = "hex",
         relative_timestamp: bool = True,
-        *args: Any,
         **kwargs: Any,
     ) -> None:
         """
@@ -67,8 +64,8 @@ class ASCReader(MessageReader):
         self.internal_events_logged = False
 
     def _extract_header(self) -> None:
-        for line in self.file:
-            line = line.strip()
+        for _line in self.file:
+            line = _line.strip()
 
             datetime_match = re.match(
                 r"date\s+\w+\s+(?P<datetime_string>.+)", line, re.IGNORECASE
@@ -93,7 +90,7 @@ class ASCReader(MessageReader):
                 )
                 continue
 
-            elif base_match:
+            if base_match:
                 base = base_match.group("base")
                 timestamp_format = base_match.group("timestamp_format")
                 self.base = base
@@ -101,15 +98,14 @@ class ASCReader(MessageReader):
                 self.timestamps_format = timestamp_format or "absolute"
                 continue
 
-            elif comment_match:
+            if comment_match:
                 continue
 
-            elif events_match:
+            if events_match:
                 self.internal_events_logged = events_match.group("no_events") is None
                 break
 
-            else:
-                break
+            break
 
     @staticmethod
     def _datetime_to_timestamp(datetime_string: str) -> float:
@@ -176,7 +172,6 @@ class ASCReader(MessageReader):
     def _process_classic_can_frame(
         self, line: str, msg_kwargs: Dict[str, Any]
     ) -> Message:
-
         # CAN error frame
         if line.strip()[0:10].lower() == "errorframe":
             # Error Frame
@@ -260,8 +255,8 @@ class ASCReader(MessageReader):
     def __iter__(self) -> Generator[Message, None, None]:
         self._extract_header()
 
-        for line in self.file:
-            line = line.strip()
+        for _line in self.file:
+            line = _line.strip()
 
             trigger_match = re.match(
                 r"begin\s+triggerblock\s+\w+\s+(?P<datetime_string>.+)",
@@ -313,7 +308,7 @@ class ASCReader(MessageReader):
         self.stop()
 
 
-class ASCWriter(FileIOMessageWriter):
+class ASCWriter(TextIOMessageWriter):
     """Logs CAN data to an ASCII log file (.asc).
 
     The measurement starts with the timestamp of the first registered message.
@@ -354,7 +349,6 @@ class ASCWriter(FileIOMessageWriter):
         self,
         file: Union[StringPathLike, TextIO],
         channel: int = 1,
-        *args: Any,
         **kwargs: Any,
     ) -> None:
         """
@@ -426,9 +420,15 @@ class ASCWriter(FileIOMessageWriter):
         self.file.write(line)
 
     def on_message_received(self, msg: Message) -> None:
+        channel = channel2int(msg.channel)
+        if channel is None:
+            channel = self.channel
+        else:
+            # Many interfaces start channel numbering at 0 which is invalid
+            channel += 1
 
         if msg.is_error_frame:
-            self.log_event(f"{self.channel}  ErrorFrame", msg.timestamp)
+            self.log_event(f"{channel}  ErrorFrame", msg.timestamp)
             return
         if msg.is_remote_frame:
             dtype = f"r {msg.dlc:x}"  # New after v8.5
@@ -439,12 +439,6 @@ class ASCWriter(FileIOMessageWriter):
         arb_id = f"{msg.arbitration_id:X}"
         if msg.is_extended_id:
             arb_id += "x"
-        channel = channel2int(msg.channel)
-        if channel is None:
-            channel = self.channel
-        else:
-            # Many interfaces start channel numbering at 0 which is invalid
-            channel += 1
         if msg.is_fd:
             flags = 0
             flags |= 1 << 12
