@@ -1,16 +1,20 @@
+import argparse
+import errno
 import re
 import sys
-import argparse
 from datetime import datetime
-import errno
-from typing import Any, Dict, List, Union, Sequence, Tuple
+from typing import TYPE_CHECKING, Any, Dict, List, Sequence, Tuple, Union
 
 import can
-from can.io import BaseRotatingLogger
-from can.io.generic import MessageWriter
+from can.util import cast_from_string
+
 from . import Bus, BusState, Logger, SizedRotatingLogger
 from .typechecking import CanFilter, CanFilters
 
+if TYPE_CHECKING:
+    from can.io import BaseRotatingLogger
+    from can.io.generic import MessageWriter
+
 
 def _create_base_argument_parser(parser: argparse.ArgumentParser) -> None:
     """Adds common options to an argument parser."""
@@ -58,7 +62,7 @@ def _create_base_argument_parser(parser: argparse.ArgumentParser) -> None:
 def _append_filter_argument(
     parser: Union[
         argparse.ArgumentParser,
-        argparse._ArgumentGroup,  # pylint: disable=protected-access
+        argparse._ArgumentGroup,
     ],
     *args: str,
     **kwargs: Any,
@@ -83,7 +87,7 @@ def _append_filter_argument(
     )
 
 
-def _create_bus(parsed_args: Any, **kwargs: Any) -> can.Bus:
+def _create_bus(parsed_args: Any, **kwargs: Any) -> can.BusABC:
     logging_level_names = ["critical", "error", "warning", "info", "debug", "subdebug"]
     can.set_logging_level(logging_level_names[min(5, parsed_args.verbosity)])
 
@@ -97,7 +101,7 @@ def _create_bus(parsed_args: Any, **kwargs: Any) -> can.Bus:
     if parsed_args.data_bitrate:
         config["data_bitrate"] = parsed_args.data_bitrate
 
-    return Bus(parsed_args.channel, **config)  # type: ignore
+    return Bus(parsed_args.channel, **config)
 
 
 def _parse_filters(parsed_args: Any) -> CanFilters:
@@ -134,18 +138,7 @@ def _parse_additional_config(
 
     args: Dict[str, Union[str, int, float, bool]] = {}
     for key, string_val in map(_split_arg, unknown_args):
-        if re.match(r"^[-+]?\d+$", string_val):
-            # value is integer
-            args[key] = int(string_val)
-        elif re.match(r"^[-+]?\d*\.\d+$", string_val):
-            # value is float
-            args[key] = float(string_val)
-        elif re.match(r"^(?:True|False)$", string_val):
-            # value is bool
-            args[key] = string_val == "True"
-        else:
-            # value is string
-            args[key] = string_val
+        args[key] = cast_from_string(string_val)
     return args
 
 
