@@ -1,17 +1,20 @@
 #!/usr/bin/env python
 
 
-import unittest
-import threading
-import random
 import logging
+import random
+import threading
+import unittest
+
+import can
 
 logging.getLogger(__file__).setLevel(logging.WARNING)
 
-# make a random bool:
-rbool = lambda: bool(round(random.random()))
 
-import can
+# make a random bool:
+def rbool():
+    return bool(round(random.random()))
+
 
 channel = "vcan0"
 
